Json

Struct Json 

pub struct Json<T>(pub T);
Available on crate feature server only.
Json wrapper for structured output

When used with tools, this wrapper indicates that the value should be serialized as structured JSON content with an associated schema. The framework will place the JSON in the structured_content field of the tool result rather than the regular content field.

Tuple Fields

0: T