pub struct CancelTaskParams {
pub meta: Option<Meta>,
pub task_id: String,
}Fields
meta: Option<Meta>Protocol-level metadata for this request (SEP-1319)
task_id: StringTrait Implementations
Sourceimpl Clone for CancelTaskParams
impl Clone for CancelTaskParams
Sourcefn clone(&self) -> CancelTaskParams
fn clone(&self) -> CancelTaskParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CancelTaskParams
impl Debug for CancelTaskParams
Sourceimpl<'de> Deserialize<'de> for CancelTaskParams
impl<'de> Deserialize<'de> for CancelTaskParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CancelTaskParams
impl JsonSchema for CancelTaskParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CancelTaskParams
impl PartialEq for CancelTaskParams
Sourceimpl RequestParamsMeta for CancelTaskParams
impl RequestParamsMeta for CancelTaskParams
Sourcefn progress_token(&self) -> Option<ProgressToken>
fn progress_token(&self) -> Option<ProgressToken>
Get the progress token from meta, if present
Sourcefn set_progress_token(&mut self, token: ProgressToken)
fn set_progress_token(&mut self, token: ProgressToken)
Set a progress token in meta
Sourceimpl Serialize for CancelTaskParams
impl Serialize for CancelTaskParams
impl StructuralPartialEq for CancelTaskParams