pub struct CompleteResult {
pub completion: CompletionInfo,
}Fields
completion: CompletionInfoTrait Implementations
Sourceimpl Clone for CompleteResult
impl Clone for CompleteResult
Sourcefn clone(&self) -> CompleteResult
fn clone(&self) -> CompleteResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompleteResult
impl Debug for CompleteResult
Sourceimpl Default for CompleteResult
impl Default for CompleteResult
Sourcefn default() -> CompleteResult
fn default() -> CompleteResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CompleteResult
impl<'de> Deserialize<'de> for CompleteResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CompleteResult> for ServerResult
impl From<CompleteResult> for ServerResult
Sourcefn from(value: CompleteResult) -> Self
fn from(value: CompleteResult) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for CompleteResult
impl JsonSchema for CompleteResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompleteResult
impl PartialEq for CompleteResult
Sourceimpl Serialize for CompleteResult
impl Serialize for CompleteResult
impl StructuralPartialEq for CompleteResult