pub struct CompletionContext {
pub arguments: Option<HashMap<String, String>>,
}Expand description
Context for completion requests providing previously resolved arguments.
This enables context-aware completion where subsequent argument completions can take into account the values of previously resolved arguments.
Fields
arguments: Option<HashMap<String, String>>Previously resolved argument values that can inform completion suggestions
Implementations
Sourceimpl CompletionContext
impl CompletionContext
Sourcepub fn with_arguments(arguments: HashMap<String, String>) -> Self
pub fn with_arguments(arguments: HashMap<String, String>) -> Self
Create a completion context with the given arguments
Sourcepub fn get_argument(&self, name: &str) -> Option<&String>
pub fn get_argument(&self, name: &str) -> Option<&String>
Get a specific argument value by name
Sourcepub fn has_arguments(&self) -> bool
pub fn has_arguments(&self) -> bool
Check if the context has any arguments
Sourcepub fn argument_names(&self) -> impl Iterator<Item = &str>
pub fn argument_names(&self) -> impl Iterator<Item = &str>
Get all argument names