pub struct CreateMessageResult {
pub model: String,
pub stop_reason: Option<String>,
pub message: SamplingMessage,
}Expand description
The result of a sampling/createMessage request containing the generated response.
This structure contains the generated message along with metadata about how the generation was performed and why it stopped.
Fields
model: StringThe identifier of the model that generated the response
stop_reason: Option<String>The reason why generation stopped (e.g., “endTurn”, “maxTokens”)
message: SamplingMessageThe generated message with role and content
Implementations
Sourceimpl CreateMessageResult
impl CreateMessageResult
pub const STOP_REASON_END_TURN: &str = "endTurn"
pub const STOP_REASON_END_SEQUENCE: &str = "stopSequence"
pub const STOP_REASON_END_MAX_TOKEN: &str = "maxTokens"