pub struct CreateTaskResult {
pub task: Task,
}Expand description
Wrapper returned by task-augmented requests (CreateTaskResult in SEP-1686).
Fields
task: TaskTrait Implementations
Sourceimpl Clone for CreateTaskResult
impl Clone for CreateTaskResult
Sourcefn clone(&self) -> CreateTaskResult
fn clone(&self) -> CreateTaskResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateTaskResult
impl Debug for CreateTaskResult
Sourceimpl<'de> Deserialize<'de> for CreateTaskResult
impl<'de> Deserialize<'de> for CreateTaskResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CreateTaskResult> for ServerResult
impl From<CreateTaskResult> for ServerResult
Sourcefn from(value: CreateTaskResult) -> Self
fn from(value: CreateTaskResult) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for CreateTaskResult
impl JsonSchema for CreateTaskResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CreateTaskResult
impl PartialEq for CreateTaskResult
Sourceimpl Serialize for CreateTaskResult
impl Serialize for CreateTaskResult
impl StructuralPartialEq for CreateTaskResult