pub struct ElicitationResponseNotificationMethod;Trait Implementations
Sourceimpl Clone for ElicitationResponseNotificationMethod
impl Clone for ElicitationResponseNotificationMethod
Sourcefn clone(&self) -> ElicitationResponseNotificationMethod
fn clone(&self) -> ElicitationResponseNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ElicitationResponseNotificationMethod
impl Default for ElicitationResponseNotificationMethod
Sourcefn default() -> ElicitationResponseNotificationMethod
fn default() -> ElicitationResponseNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ElicitationResponseNotificationMethod
impl<'de> Deserialize<'de> for ElicitationResponseNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ElicitationResponseNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ElicitationResponseNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ElicitationResponseNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for ElicitationResponseNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ElicitationResponseNotificationMethod
impl PartialEq for ElicitationResponseNotificationMethod
Sourcefn eq(&self, other: &ElicitationResponseNotificationMethod) -> bool
fn eq(&self, other: &ElicitationResponseNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ElicitationResponseNotificationMethod
impl Eq for ElicitationResponseNotificationMethod
impl StructuralPartialEq for ElicitationResponseNotificationMethod