ErrorData

Struct ErrorData 

pub struct ErrorData {
    pub code: ErrorCode,
    pub message: Cow<'static, str>,
    pub data: Option<Value>,
}
Error information for JSON-RPC error responses.

This structure follows the JSON-RPC 2.0 specification for error reporting, providing a standardized way to communicate errors between clients and servers.

Fields

code: ErrorCode

The error type that occurred (using standard JSON-RPC error codes)

message: Cow<'static, str>

A short description of the error. The message SHOULD be limited to a concise single sentence.

data: Option<Value>

Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.).

Implementations

Source

impl ErrorData

pub fn new( code: ErrorCode, message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self

pub fn resource_not_found( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self

pub fn parse_error( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self

pub fn invalid_request( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self

pub fn method_not_found<M: ConstString>() -> Self

pub fn invalid_params( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self

pub fn internal_error( message: impl Into<Cow<'static, str>>, data: Option<Value>, ) -> Self