pub struct GetPromptRequestParams {
pub meta: Option<Meta>,
pub name: String,
pub arguments: Option<JsonObject>,
}Expand description
Parameters for retrieving a specific prompt
Fields
meta: Option<Meta>Protocol-level metadata for this request (SEP-1319)
name: Stringarguments: Option<JsonObject>Trait Implementations
Sourceimpl Clone for GetPromptRequestParams
impl Clone for GetPromptRequestParams
Sourcefn clone(&self) -> GetPromptRequestParams
fn clone(&self) -> GetPromptRequestParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetPromptRequestParams
impl Debug for GetPromptRequestParams
Sourceimpl<'de> Deserialize<'de> for GetPromptRequestParams
impl<'de> Deserialize<'de> for GetPromptRequestParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetPromptRequestParams
impl JsonSchema for GetPromptRequestParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetPromptRequestParams
impl PartialEq for GetPromptRequestParams
Sourceimpl RequestParamsMeta for GetPromptRequestParams
impl RequestParamsMeta for GetPromptRequestParams
Sourcefn progress_token(&self) -> Option<ProgressToken>
fn progress_token(&self) -> Option<ProgressToken>
Get the progress token from meta, if present
Sourcefn set_progress_token(&mut self, token: ProgressToken)
fn set_progress_token(&mut self, token: ProgressToken)
Set a progress token in meta
Sourceimpl Serialize for GetPromptRequestParams
impl Serialize for GetPromptRequestParams
impl StructuralPartialEq for GetPromptRequestParams