pub struct GetPromptResult {
pub description: Option<String>,
pub messages: Vec<PromptMessage>,
}Fields
description: Option<String>messages: Vec<PromptMessage>Trait Implementations
Sourceimpl Clone for GetPromptResult
impl Clone for GetPromptResult
Sourcefn clone(&self) -> GetPromptResult
fn clone(&self) -> GetPromptResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetPromptResult
impl Debug for GetPromptResult
Sourceimpl<'de> Deserialize<'de> for GetPromptResult
impl<'de> Deserialize<'de> for GetPromptResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetPromptResult> for ServerResult
impl From<GetPromptResult> for ServerResult
Sourcefn from(value: GetPromptResult) -> Self
fn from(value: GetPromptResult) -> Self
Converts to this type from the input type.
Sourceimpl IntoGetPromptResult for GetPromptResult
Available on crate feature server only.
impl IntoGetPromptResult for GetPromptResult
Available on crate feature
server only.fn into_get_prompt_result(self) -> Result<GetPromptResult, ErrorData>
Sourceimpl JsonSchema for GetPromptResult
impl JsonSchema for GetPromptResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetPromptResult
impl PartialEq for GetPromptResult
Sourceimpl Serialize for GetPromptResult
impl Serialize for GetPromptResult
impl StructuralPartialEq for GetPromptResult