pub struct GetTaskInfoResult {
pub task: Option<Task>,
}Fields
task: Option<Task>Trait Implementations
Sourceimpl Clone for GetTaskInfoResult
impl Clone for GetTaskInfoResult
Sourcefn clone(&self) -> GetTaskInfoResult
fn clone(&self) -> GetTaskInfoResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetTaskInfoResult
impl Debug for GetTaskInfoResult
Sourceimpl<'de> Deserialize<'de> for GetTaskInfoResult
impl<'de> Deserialize<'de> for GetTaskInfoResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetTaskInfoResult> for ServerResult
impl From<GetTaskInfoResult> for ServerResult
Sourcefn from(value: GetTaskInfoResult) -> Self
fn from(value: GetTaskInfoResult) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for GetTaskInfoResult
impl JsonSchema for GetTaskInfoResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetTaskInfoResult
impl PartialEq for GetTaskInfoResult
Sourceimpl Serialize for GetTaskInfoResult
impl Serialize for GetTaskInfoResult
impl StructuralPartialEq for GetTaskInfoResult