pub struct InitializedNotificationMethod;Trait Implementations
Sourceimpl Clone for InitializedNotificationMethod
impl Clone for InitializedNotificationMethod
Sourcefn clone(&self) -> InitializedNotificationMethod
fn clone(&self) -> InitializedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InitializedNotificationMethod
impl Default for InitializedNotificationMethod
Sourcefn default() -> InitializedNotificationMethod
fn default() -> InitializedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InitializedNotificationMethod
impl<'de> Deserialize<'de> for InitializedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<InitializedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<InitializedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InitializedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for InitializedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InitializedNotificationMethod
impl PartialEq for InitializedNotificationMethod
Sourcefn eq(&self, other: &InitializedNotificationMethod) -> bool
fn eq(&self, other: &InitializedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for InitializedNotificationMethod
impl Eq for InitializedNotificationMethod
impl StructuralPartialEq for InitializedNotificationMethod