pub struct ListResourceTemplatesRequestMethod;Trait Implementations
Sourceimpl Clone for ListResourceTemplatesRequestMethod
impl Clone for ListResourceTemplatesRequestMethod
Sourcefn clone(&self) -> ListResourceTemplatesRequestMethod
fn clone(&self) -> ListResourceTemplatesRequestMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListResourceTemplatesRequestMethod
impl Default for ListResourceTemplatesRequestMethod
Sourcefn default() -> ListResourceTemplatesRequestMethod
fn default() -> ListResourceTemplatesRequestMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ListResourceTemplatesRequestMethod
impl<'de> Deserialize<'de> for ListResourceTemplatesRequestMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ListResourceTemplatesRequestMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ListResourceTemplatesRequestMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListResourceTemplatesRequestMethod
Available on crate feature schemars only.
impl JsonSchema for ListResourceTemplatesRequestMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListResourceTemplatesRequestMethod
impl PartialEq for ListResourceTemplatesRequestMethod
Sourcefn eq(&self, other: &ListResourceTemplatesRequestMethod) -> bool
fn eq(&self, other: &ListResourceTemplatesRequestMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ListResourceTemplatesRequestMethod
impl Eq for ListResourceTemplatesRequestMethod
impl StructuralPartialEq for ListResourceTemplatesRequestMethod