pub struct LoggingMessageNotificationMethod;Trait Implementations
Sourceimpl Clone for LoggingMessageNotificationMethod
impl Clone for LoggingMessageNotificationMethod
Sourcefn clone(&self) -> LoggingMessageNotificationMethod
fn clone(&self) -> LoggingMessageNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for LoggingMessageNotificationMethod
impl Default for LoggingMessageNotificationMethod
Sourcefn default() -> LoggingMessageNotificationMethod
fn default() -> LoggingMessageNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LoggingMessageNotificationMethod
impl<'de> Deserialize<'de> for LoggingMessageNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<LoggingMessageNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<LoggingMessageNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoggingMessageNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for LoggingMessageNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LoggingMessageNotificationMethod
impl PartialEq for LoggingMessageNotificationMethod
Sourcefn eq(&self, other: &LoggingMessageNotificationMethod) -> bool
fn eq(&self, other: &LoggingMessageNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for LoggingMessageNotificationMethod
impl Eq for LoggingMessageNotificationMethod
impl StructuralPartialEq for LoggingMessageNotificationMethod