Notification

Struct Notification 

pub struct Notification<M = String, P = JsonObject> {
    pub method: M,
    pub params: P,
    pub extensions: Extensions,
}

Fields

method: Mparams: Pextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate

Implementations

Source

impl<M: Default, P> Notification<M, P>

pub fn new(params: P) -> Self