pub struct PromptListChangedNotificationMethod;Trait Implementations
Sourceimpl Clone for PromptListChangedNotificationMethod
impl Clone for PromptListChangedNotificationMethod
Sourcefn clone(&self) -> PromptListChangedNotificationMethod
fn clone(&self) -> PromptListChangedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PromptListChangedNotificationMethod
impl Default for PromptListChangedNotificationMethod
Sourcefn default() -> PromptListChangedNotificationMethod
fn default() -> PromptListChangedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PromptListChangedNotificationMethod
impl<'de> Deserialize<'de> for PromptListChangedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<PromptListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<PromptListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptListChangedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for PromptListChangedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromptListChangedNotificationMethod
impl PartialEq for PromptListChangedNotificationMethod
Sourcefn eq(&self, other: &PromptListChangedNotificationMethod) -> bool
fn eq(&self, other: &PromptListChangedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PromptListChangedNotificationMethod
impl Eq for PromptListChangedNotificationMethod
impl StructuralPartialEq for PromptListChangedNotificationMethod