pub struct RequestOptionalParam<M = String, P = JsonObject> {
pub method: M,
pub params: Option<P>,
pub extensions: Extensions,
}Fields
method: Mparams: Option<P>extensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate
Implementations
Sourceimpl<M: Default, P> RequestOptionalParam<M, P>
impl<M: Default, P> RequestOptionalParam<M, P>
pub fn with_param(params: P) -> Self