pub struct ResourceListChangedNotificationMethod;Trait Implementations
Sourceimpl Clone for ResourceListChangedNotificationMethod
impl Clone for ResourceListChangedNotificationMethod
Sourcefn clone(&self) -> ResourceListChangedNotificationMethod
fn clone(&self) -> ResourceListChangedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ResourceListChangedNotificationMethod
impl Default for ResourceListChangedNotificationMethod
Sourcefn default() -> ResourceListChangedNotificationMethod
fn default() -> ResourceListChangedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResourceListChangedNotificationMethod
impl<'de> Deserialize<'de> for ResourceListChangedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ResourceListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ResourceListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceListChangedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for ResourceListChangedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResourceListChangedNotificationMethod
impl PartialEq for ResourceListChangedNotificationMethod
Sourcefn eq(&self, other: &ResourceListChangedNotificationMethod) -> bool
fn eq(&self, other: &ResourceListChangedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ResourceListChangedNotificationMethod
impl Eq for ResourceListChangedNotificationMethod
impl StructuralPartialEq for ResourceListChangedNotificationMethod