pub struct ResourceUpdatedNotificationMethod;Trait Implementations
Sourceimpl Clone for ResourceUpdatedNotificationMethod
impl Clone for ResourceUpdatedNotificationMethod
Sourcefn clone(&self) -> ResourceUpdatedNotificationMethod
fn clone(&self) -> ResourceUpdatedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ResourceUpdatedNotificationMethod
impl Default for ResourceUpdatedNotificationMethod
Sourcefn default() -> ResourceUpdatedNotificationMethod
fn default() -> ResourceUpdatedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResourceUpdatedNotificationMethod
impl<'de> Deserialize<'de> for ResourceUpdatedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ResourceUpdatedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ResourceUpdatedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResourceUpdatedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for ResourceUpdatedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResourceUpdatedNotificationMethod
impl PartialEq for ResourceUpdatedNotificationMethod
Sourcefn eq(&self, other: &ResourceUpdatedNotificationMethod) -> bool
fn eq(&self, other: &ResourceUpdatedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ResourceUpdatedNotificationMethod
impl Eq for ResourceUpdatedNotificationMethod
impl StructuralPartialEq for ResourceUpdatedNotificationMethod