pub struct RootsListChangedNotificationMethod;Trait Implementations
Sourceimpl Clone for RootsListChangedNotificationMethod
impl Clone for RootsListChangedNotificationMethod
Sourcefn clone(&self) -> RootsListChangedNotificationMethod
fn clone(&self) -> RootsListChangedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RootsListChangedNotificationMethod
impl Default for RootsListChangedNotificationMethod
Sourcefn default() -> RootsListChangedNotificationMethod
fn default() -> RootsListChangedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RootsListChangedNotificationMethod
impl<'de> Deserialize<'de> for RootsListChangedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<RootsListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<RootsListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RootsListChangedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for RootsListChangedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RootsListChangedNotificationMethod
impl PartialEq for RootsListChangedNotificationMethod
Sourcefn eq(&self, other: &RootsListChangedNotificationMethod) -> bool
fn eq(&self, other: &RootsListChangedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RootsListChangedNotificationMethod
impl Eq for RootsListChangedNotificationMethod
impl StructuralPartialEq for RootsListChangedNotificationMethod