GetPromptRequest

Type Alias GetPromptRequest 

pub type GetPromptRequest = Request<GetPromptRequestMethod, GetPromptRequestParams>;
Request to get a specific prompt

Aliased Type

pub struct GetPromptRequest {
    pub method: GetPromptRequestMethod,
    pub params: GetPromptRequestParams,
    pub extensions: Extensions,
}

Fields

method: GetPromptRequestMethodparams: GetPromptRequestParamsextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate