pub type GetTaskInfoRequest = Request<GetTaskInfoMethod, GetTaskInfoParams>;Aliased Type
pub struct GetTaskInfoRequest {
pub method: GetTaskInfoMethod,
pub params: GetTaskInfoParams,
pub extensions: Extensions,
}Fields
method: GetTaskInfoMethodparams: GetTaskInfoParamsextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate