InitializedNotification

Type Alias InitializedNotification 

pub type InitializedNotification = NotificationNoParam<InitializedNotificationMethod>;
This notification is sent from the client to the server after initialization has finished.

Aliased Type

pub struct InitializedNotification {
    pub method: InitializedNotificationMethod,
    pub extensions: Extensions,
}

Fields

method: InitializedNotificationMethodextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate