LoggingMessageNotification

Type Alias LoggingMessageNotification 

pub type LoggingMessageNotification = Notification<LoggingMessageNotificationMethod, LoggingMessageNotificationParam>;
Notification containing a log message

Aliased Type

pub struct LoggingMessageNotification {
    pub method: LoggingMessageNotificationMethod,
    pub params: LoggingMessageNotificationParam,
    pub extensions: Extensions,
}

Fields

method: LoggingMessageNotificationMethodparams: LoggingMessageNotificationParamextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate