PromptListChangedNotification

Type Alias PromptListChangedNotification 

pub type PromptListChangedNotification = NotificationNoParam<PromptListChangedNotificationMethod>;
Notification sent when the list of available prompts changes

Aliased Type

pub struct PromptListChangedNotification {
    pub method: PromptListChangedNotificationMethod,
    pub extensions: Extensions,
}

Fields

method: PromptListChangedNotificationMethodextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate