ResourceListChangedNotification

Type Alias ResourceListChangedNotification 

pub type ResourceListChangedNotification = NotificationNoParam<ResourceListChangedNotificationMethod>;
Notification sent when the list of available resources changes

Aliased Type

pub struct ResourceListChangedNotification {
    pub method: ResourceListChangedNotificationMethod,
    pub extensions: Extensions,
}

Fields

method: ResourceListChangedNotificationMethodextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate