ResourceUpdatedNotification

Type Alias ResourceUpdatedNotification 

pub type ResourceUpdatedNotification = Notification<ResourceUpdatedNotificationMethod, ResourceUpdatedNotificationParam>;
Notification sent when a subscribed resource is updated

Aliased Type

pub struct ResourceUpdatedNotification {
    pub method: ResourceUpdatedNotificationMethod,
    pub params: ResourceUpdatedNotificationParam,
    pub extensions: Extensions,
}

Fields

method: ResourceUpdatedNotificationMethodparams: ResourceUpdatedNotificationParamextensions: Extensions

extensions will carry anything possible in the context, including Meta

this is similar with the Extensions in http crate