ClientInitializeError

Enum ClientInitializeError 

pub enum ClientInitializeError {
    ExpectedInitResponse(Option<ServerJsonRpcMessage>),
    ExpectedInitResult(Option<ServerResult>),
    ConflictInitResponseId(RequestId, RequestId),
    ConnectionClosed(String),
    TransportError {
        error: DynamicTransportError,
        context: Cow<'static, str>,
    },
    JsonRpcError(ErrorData),
    Cancelled,
}
Available on (crate features client or server) and crate feature client only.
It represents the error that may occur when serving the client.

if you want to handle the error, you can use serve_client_with_ct or serve_client with Result<RunningService<RoleClient, S>, ClientError>

Variants



ExpectedInitResponse(Option<ServerJsonRpcMessage>)



ExpectedInitResult(Option<ServerResult>)



ConflictInitResponseId(RequestId, RequestId)



ConnectionClosed(String)



TransportError

Fields

context: Cow<'static, str>


JsonRpcError(ErrorData)



Cancelled

Implementations

Source

impl ClientInitializeError

pub fn transport<T: Transport<RoleClient> + 'static>( error: T::Error, context: impl Into<Cow<'static, str>>, ) -> Self