pub enum ServerInitializeError {
ExpectedInitializeRequest(Option<ClientJsonRpcMessage>),
ExpectedInitializedNotification(Option<ClientJsonRpcMessage>),
ConnectionClosed(String),
UnexpectedInitializeResponse(ServerResult),
InitializeFailed(ErrorData),
UnsupportedProtocolVersion(ProtocolVersion),
TransportError {
error: DynamicTransportError,
context: Cow<'static, str>,
},
Cancelled,
}Available on (crate features
client or server) and crate feature server only.Expand description
It represents the error that may occur when serving the server.
if you want to handle the error, you can use serve_server_with_ct or serve_server with Result<RunningService<RoleServer, S>, ServerError>
Variants
ExpectedInitializeRequest(Option<ClientJsonRpcMessage>)
ExpectedInitializedNotification(Option<ClientJsonRpcMessage>)
ConnectionClosed(String)
UnexpectedInitializeResponse(ServerResult)
InitializeFailed(ErrorData)
UnsupportedProtocolVersion(ProtocolVersion)
TransportError
Cancelled
Implementations