pub struct StreamableHttpServerConfig {
pub sse_keep_alive: Option<Duration>,
pub sse_retry: Option<Duration>,
pub stateful_mode: bool,
pub cancellation_token: CancellationToken,
}Available on crate features
transport-streamable-http-server-session and transport-streamable-http-server only.Fields
sse_keep_alive: Option<Duration>The ping message duration for SSE connections.
sse_retry: Option<Duration>The retry interval for SSE priming events.
stateful_mode: boolIf true, the server will create a session for each request and keep it alive. When enabled, SSE priming events are sent to enable client reconnection.
cancellation_token: CancellationTokenCancellation token for the Streamable HTTP server.
When this token is cancelled, all active sessions are terminated and the server stops accepting new requests.