StreamableHttpService

Struct StreamableHttpService 

pub struct StreamableHttpService<S, M = LocalSessionManager> {
    pub config: StreamableHttpServerConfig,
    /* private fields */
}
Available on crate features transport-streamable-http-server-session and transport-streamable-http-server only.
Streamable Http Server

Extract information from raw http request

The http service will consume the request body, however the rest part will be remain and injected into crate::model::Extensions, which you can get from crate::service::RequestContext.

use mcpkit_rs::handler::server::tool::Extension;
use http::request::Parts;
async fn my_tool(Extension(parts): Extension<Parts>) {
    tracing::info!("http parts:{parts:?}")
}

Fields

config: StreamableHttpServerConfig

Implementations

Source

impl<S, M> StreamableHttpService<S, M>
where S: Service<RoleServer> + Send + 'static, M: SessionManager,

pub fn new( service_factory: impl Fn() -> Result<S, Error> + Send + Sync + 'static, session_manager: Arc<M>, config: StreamableHttpServerConfig, ) -> Self

pub async fn handle<B>( &self, request: Request<B>, ) -> Response<BoxBody<Bytes, Infallible>>
where B: Body + Send + 'static, B::Error: Display,