pub struct Parameters<P>(pub P);Available on crate feature
server only.Expand description
Parameter extractor for tools and prompts
When used in tool and prompt handlers, this wrapper extracts and deserializes
parameters from the incoming request. The framework will automatically parse
the JSON arguments from tool calls or prompt arguments and deserialize them
into the specified type P.
The #[serde(transparent)] attribute ensures that the wrapper doesn’t add
an extra layer in the JSON structure - it directly delegates serialization
and deserialization to the inner type P.
Usage
Use Parameters<T> as a parameter in your tool or prompt handler functions:
#[derive(Deserialize, JsonSchema)]
struct CalculationRequest {
operation: String,
a: f64,
b: f64,
}
// In a tool handler
async fn calculate(params: Parameters<CalculationRequest>) -> Result<String, String> {
let request = params.0; // Extract the inner value
match request.operation.as_str() {
"add" => Ok((request.a + request.b).to_string()),
_ => Err("Unknown operation".to_string()),
}
}The framework handles the extraction automatically:
- For tools: Parses the
argumentsfield from tool call requests - For prompts: Parses the
argumentsfield from prompt requests - Returns appropriate error responses if deserialization fails
Tuple Fields
0: PTrait Implementations
Sourceimpl<P: Clone> Clone for Parameters<P>
impl<P: Clone> Clone for Parameters<P>
Sourcefn clone(&self) -> Parameters<P>
fn clone(&self) -> Parameters<P>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<P: Debug> Debug for Parameters<P>
impl<P: Debug> Debug for Parameters<P>
Sourceimpl<'de, P> Deserialize<'de> for Parameters<P>where
P: Deserialize<'de>,
impl<'de, P> Deserialize<'de> for Parameters<P>where
P: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<S, P> FromContextPart<PromptContext<'_, S>> for Parameters<P>where
P: DeserializeOwned,
impl<S, P> FromContextPart<PromptContext<'_, S>> for Parameters<P>where
P: DeserializeOwned,
fn from_context_part( context: &mut PromptContext<'_, S>, ) -> Result<Self, ErrorData>
Sourceimpl<S, P> FromContextPart<ToolCallContext<'_, S>> for Parameters<P>where
P: DeserializeOwned,
impl<S, P> FromContextPart<ToolCallContext<'_, S>> for Parameters<P>where
P: DeserializeOwned,
fn from_context_part( context: &mut ToolCallContext<'_, S>, ) -> Result<Self, ErrorData>
Sourceimpl<P: JsonSchema> JsonSchema for Parameters<P>
impl<P: JsonSchema> JsonSchema for Parameters<P>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl<P> Freeze for Parameters<P>where
P: Freeze,
impl<P> RefUnwindSafe for Parameters<P>where
P: RefUnwindSafe,
impl<P> Send for Parameters<P>where
P: Send,
impl<P> Sync for Parameters<P>where
P: Sync,
impl<P> Unpin for Parameters<P>where
P: Unpin,
impl<P> UnwindSafe for Parameters<P>where
P: UnwindSafe,