pub type LoggingMessageNotification = Notification<LoggingMessageNotificationMethod, LoggingMessageNotificationParam>;Expand description
Notification containing a log message
Aliased Type
pub struct LoggingMessageNotification {
pub method: LoggingMessageNotificationMethod,
pub params: LoggingMessageNotificationParam,
pub extensions: Extensions,
}Fields
method: LoggingMessageNotificationMethodparams: LoggingMessageNotificationParamextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate