pub type PromptListChangedNotification = NotificationNoParam<PromptListChangedNotificationMethod>;Expand description
Notification sent when the list of available prompts changes
Aliased Type
pub struct PromptListChangedNotification {
pub method: PromptListChangedNotificationMethod,
pub extensions: Extensions,
}Fields
method: PromptListChangedNotificationMethodextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate