pub type ResourceListChangedNotification = NotificationNoParam<ResourceListChangedNotificationMethod>;Expand description
Notification sent when the list of available resources changes
Aliased Type
pub struct ResourceListChangedNotification {
pub method: ResourceListChangedNotificationMethod,
pub extensions: Extensions,
}Fields
method: ResourceListChangedNotificationMethodextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate