pub type SetLevelRequest = Request<SetLevelRequestMethod, SetLevelRequestParams>;Expand description
Request to set the logging level
Aliased Type
pub struct SetLevelRequest {
pub method: SetLevelRequestMethod,
pub params: SetLevelRequestParams,
pub extensions: Extensions,
}Fields
method: SetLevelRequestMethodparams: SetLevelRequestParamsextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate