pub struct StreamableHttpService<S, M = LocalSessionManager> {
pub config: StreamableHttpServerConfig,
/* private fields */
}Available on crate features
transport-streamable-http-server-session and transport-streamable-http-server only.Expand description
Streamable Http Server
Extract information from raw http request
The http service will consume the request body, however the rest part will be remain and injected into crate::model::Extensions,
which you can get from crate::service::RequestContext.
use mcpkit_rs::handler::server::tool::Extension;
use http::request::Parts;
async fn my_tool(Extension(parts): Extension<Parts>) {
tracing::info!("http parts:{parts:?}")
}Fields
config: StreamableHttpServerConfigImplementations
Sourceimpl<S, M> StreamableHttpService<S, M>
impl<S, M> StreamableHttpService<S, M>